@@ -4,6 +4,7 @@ import numpy as np
 import pandas as pd
 from tabulate import tabulate
 import tensorflow as tf
+import tensorflow_addons as tfa
 
 from sknlp.vocab import Vocab
 from sknlp.data import ClassificationDataset
@@ -26,7 +27,8 @@ class DeepClassifier(SupervisedNLPModel):
         embedding_size: int = 100,
         use_batch_normalization: bool = True,
         text2vec: Optional[Text2vec] = None,
-        loss: Optional[Tuple[tf.keras.losses.Loss, Dict[str, Any]]] = None,
+        loss: Optional[str] = None,
+        loss_kwargs: Optional[Dict[str, Any]] = None,
         **kwargs
     ):
         classes = list(classes)
@@ -47,6 +49,7 @@ class DeepClassifier(SupervisedNLPModel):
         self._is_multilabel = is_multilabel
         self._use_batch_normalization = use_batch_normalization
         self._loss = loss
+        self._loss_kwargs = loss_kwargs
 
     @property
     def is_multilabel(self):
@@ -58,9 +61,10 @@ class DeepClassifier(SupervisedNLPModel):
 
     def get_loss(self, *args, **kwargs):
         if self.is_multilabel:
-            if self._loss is not None:
-                loss_func, loss_kwargs = self._loss
-                return loss_func(from_logits=True, **loss_kwargs)
+            if self._loss == "focal":
+                return tfa.losses.SigmoidFocalCrossEntropy(
+                    from_logits=True, **self._loss_kwargs
+                )
             return tf.keras.losses.BinaryCrossentropy(from_logits=True)
         else:
             return tf.keras.losses.CategoricalCrossentropy(from_logits=True)
