@@ -25,8 +25,7 @@ class TextRNNClassifier(DeepClassifier):
         rnn_output_dropout: float = 0.5,
         num_fc_layers: int = 2,
         fc_hidden_size: int = 128,
-        fc_activation: str = "relu",
-        fc_last_activation: str = "tanh",
+        fc_activation: str = "tanh",
         fc_momentum: float = 0.9,
         fc_epsilon: float = 1e-5,
         rnn_kernel_initializer="glorot_uniform",
@@ -78,7 +77,6 @@ class TextRNNClassifier(DeepClassifier):
         self.num_fc_layers = num_fc_layers
         self.fc_hidden_size = fc_hidden_size
         self.fc_activation = fc_activation
-        self.fc_last_activation = fc_last_activation
         self.fc_momentum = fc_momentum
         self.fc_epsilon = fc_epsilon
 
@@ -114,8 +112,7 @@ class TextRNNClassifier(DeepClassifier):
             hidden_size=self.fc_hidden_size,
             output_size=self.num_classes,
             activation=self.fc_activation,
-            last_activation=self.fc_last_activation,
-            batch_normal=self.use_batch_normal,
+            batch_normalization=self.use_batch_normalization,
             momentum=self.fc_momentum,
             epsilon=self.fc_epsilon,
             name="mlp",
