@@ -121,11 +121,15 @@ class SupervisedNLPModel(BaseNLPModel):
             df, self.text2vec.vocab, self.text2vec.segmenter, self.classes
         )
 
-    def compile_optimizer(self, **kwargs) -> None:
+    def compile_optimizer(self, optimizer_name, **kwargs) -> None:
         if not self._built:
             self.build()
         weight_decay = kwargs.pop("weight_decay", 0)
-        if weight_decay > 0:
+        if optimizer_name != "adam":
+            optimizer = tf.keras.optimizers.deserialize(
+                {"class_name": optimizer_name, "config": kwargs}
+            )
+        elif weight_decay > 0:
             optimizer = tfa.optimizers.AdamW(weight_decay, **kwargs)
         else:
             optimizer = tfa.optimizers.LazyAdam(**kwargs)
@@ -146,6 +150,8 @@ class SupervisedNLPModel(BaseNLPModel):
         valid_dataset: NLPDataset = None,
         batch_size: int = 128,
         n_epochs: int = 10,
+        optimizer: str = "adam",
+        optimizer_kwargs: Optional[Dict[str, Any]] = None,
         learning_rate: float = 1e-3,
         weight_decay: float = 0.0,
         clip: Optional[float] = 5.0,
@@ -176,13 +182,15 @@ class SupervisedNLPModel(BaseNLPModel):
         if self.valid_dataset is not None:
             valid_tf_dataset = self.valid_dataset.batchify(batch_size, shuffle=False)
 
+        optimizer_kwargs = optimizer_kwargs or dict()
         optimizer_kwargs = {
             "learning_rate": learning_rate,
             "weight_decay": weight_decay,
+            **optimizer_kwargs,
         }
         if clip is not None:
             optimizer_kwargs["clipnorm"] = clip
-        self.compile_optimizer(**optimizer_kwargs)
+        self.compile_optimizer(optimizer, **optimizer_kwargs)
 
         monitor = "val_loss"
         monitor_direction = "min"
